@@ -2,9 +2,9 @@
 
 BUILD_DIR=$PWD
 
-if [ -f "xmlrpc-c.tar.gz" ]; then
+if [ -f "${XMLRPC_DIR}xmlrpc-c.tar.gz" ]; then
 (
-    tar xzvf xmlrpc-c.tar.gz
+    tar xzvf ${XMLRPC_DIR}xmlrpc-c.tar.gz
     mv xmlrpc-c ..
 )
 fi
